@@ -249,12 +249,8 @@ class SupeRSS:
     d = feed_data.copy()
 
     # TODO: better merge heuristics
-    if len(extracted_data['text']) > feed_data['text']:
-      d['article_html'] = extracted_data['article_html']
-      d['text'] = extracted_data['text']
-
-    if len(extracted_data['title']) > feed_data['title'] and feed_data['title'] is not None:
-      d['title'] = extracted_data['title']
+    d['article_html'] = extracted_data['article_html']
+    d['text'] = extracted_data['text']
 
     # add lists together
     d['tags'] = list(set(feed_data['tags'] + extracted_data['tags']))
@@ -274,16 +270,16 @@ class SupeRSS:
     return self.merge_extracted_data(entry, extracted_data)
 
   def run_concurrent(self, func, iterator):
-    pool = Pool(self.num_workers)
-    if self.concurrent:
-      if imported_gevent:
-        for result in pool.imap_unordered(func, iterator):
-          yield result 
 
-      else:
-        logger.warn('SupeRSS requires gevent run concurrently.')
-        for item in iterator:
-          yield func(item)
+    if imported_gevent and self.concurrent:
+      pool = Pool(self.num_workers)
+      for result in pool.imap_unordered(func, iterator):
+        yield result 
+
+    elif not imported_gevent and self.concurrent:
+      logger.warn('SupeRSS requires gevent run concurrently.')
+      for item in iterator:
+        yield func(item)
 
     else:
       for item in iterator:
